From: Greg KH <gregkh@suse.de>
To: linux-kernel@vger.kernel.org, stable@kernel.org
Cc: Justin Forbes <jmforbes@linuxtx.org>,
Zwane Mwaikambo <zwane@arm.linux.org.uk>,
"Theodore Ts'o" <tytso@mit.edu>,
Randy Dunlap <rdunlap@xenotime.net>,
Dave Jones <davej@redhat.com>,
Chuck Wolber <chuckw@quantumlinux.com>,
Chris Wedgwood <reviews@ml.cw.f00f.org>,
Michael Krufky <mkrufky@linuxtv.org>,
Chuck Ebbert <cebbert@redhat.com>,
Domenico Andreoli <cavokz@gmail.com>, Willy Tarreau <w@1wt.eu>,
Rodrigo Rubira Branco <rbranco@la.checkpoint.com>,
Jake Edge <jake@lwn.net>, Eugene Teo <eteo@redhat.com>,
torvalds@linux-foundation.org, akpm@linux-foundation.org,
alan@lxorguk.ukuu.org.uk, Shaohua Li <shaohua.li@intel.com>,
Alex Chiang <achiang@hp.com>,
Jesse Barnes <jbarnes@virtuousgeek.org>
Subject: [patch 35/53] PCI: properly clean up ASPM link state on device remove
Date: Tue, 10 Feb 2009 11:00:57 -0800 [thread overview]
Message-ID: <20090210190057.GJ14308@kroah.com> (raw)
In-Reply-To: <20090210185924.GA14308@kroah.com>
[-- Attachment #1: pci-properly-clean-up-aspm-link-state-on-device-remove.patch --]
[-- Type: text/plain, Size: 1672 bytes --]
2.6.28-stable review patch. If anyone has any objections, please let us know.
------------------
From: Alex Chiang <achiang@hp.com>
commit 3419c75e15f82c3ab09bd944fddbde72c9e4b3ea upstream.
We only want to disable ASPM when the last function is removed from
the parent's device list. We determine this by checking to see if
the parent's device list is completely empty.
Unfortunately, we never hit that code because the parent is considered
an upstream port, and never had an ASPM link_state associated with it.
The early check for !link_state causes us to return early, we never
discover that our device list is empty, and thus we never remove the
downstream ports' link_state nodes.
Instead of checking to see if the parent's device list is empty, we can
check to see if we are the last device on the list, and if so, then we
know that we can clean up properly.
Cc: Shaohua Li <shaohua.li@intel.com>
Signed-off-by: Alex Chiang <achiang@hp.com>
Signed-off-by: Jesse Barnes <jbarnes@virtuousgeek.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
---
drivers/pci/pcie/aspm.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
--- a/drivers/pci/pcie/aspm.c
+++ b/drivers/pci/pcie/aspm.c
@@ -713,9 +713,9 @@ void pcie_aspm_exit_link_state(struct pc
/*
* All PCIe functions are in one slot, remove one function will remove
* the the whole slot, so just wait
*/
- if (!list_empty(&parent->subordinate->devices))
+ if (!list_is_last(&pdev->bus_list, &parent->subordinate->devices))
goto out;
/* All functions are removed, so just disable ASPM for the link */
next prev parent reply other threads:[~2009-02-10 19:16 UTC|newest]
Thread overview: 54+ messages / expand[flat|nested] mbox.gz Atom feed top
[not found] <20090210185337.000769713@mini.kroah.org>
2009-02-10 18:59 ` [patch 00/53] 2.6.28-stable review Greg KH
2009-02-10 18:59 ` [patch 01/53] sgi-xp: fix writing past the end of kzalloc()d space Greg KH
2009-02-10 18:59 ` [patch 02/53] do_wp_page: fix regression with execute in place Greg KH
2009-02-10 18:59 ` [patch 03/53] wait: prevent exclusive waiter starvation Greg KH
2009-02-10 18:59 ` [patch 04/53] shm: fix shmctl(SHM_INFO) lockup with !CONFIG_SHMEM Greg KH
2009-02-10 18:59 ` [patch 05/53] revert "rlimit: permit setting RLIMIT_NOFILE to RLIM_INFINITY" Greg KH
2009-02-10 18:59 ` [patch 06/53] prevent kprobes from catching spurious page faults Greg KH
2009-02-10 18:59 ` [patch 07/53] sound: usb-audio: handle wMaxPacketSize for FIXED_ENDPOINT devices Greg KH
2009-02-10 18:59 ` [patch 08/53] md: Ensure an md array never has too many devices Greg KH
2009-02-10 18:59 ` [patch 09/53] md: Fix a bug in linear.c causing which_dev() to return the wrong device Greg KH
2009-02-10 19:00 ` [patch 10/53] ACPI: Enable bit 11 in _PDC to advertise hw coord Greg KH
2009-02-10 19:00 ` [patch 11/53] ACPI: dock: Dont eval _STA on every show_docked sysfs read Greg KH
2009-02-10 19:00 ` [patch 12/53] ieee1394: ohci1394: increase AT req. retries, fix ack_busy_X from Panasonic camcorders and others Greg KH
2009-02-10 19:00 ` [patch 13/53] firewire: ohci: " Greg KH
2009-02-10 19:00 ` [patch 14/53] firewire: sbp2: fix DMA mapping leak on the failure path Greg KH
2009-02-10 19:00 ` [patch 15/53] firewire: sbp2: add workarounds for 2nd and 3rd generation iPods Greg KH
2009-02-10 19:00 ` [patch 16/53] ieee1394: " Greg KH
2009-02-10 19:00 ` [patch 17/53] module: remove over-zealous check in __module_get() Greg KH
2009-02-10 19:00 ` [patch 18/53] serial: RS485 ioctl structure uses __u32 include linux/types.h Greg KH
2009-02-10 19:00 ` [patch 19/53] x86: APIC: enable workaround on AMD Fam10h CPUs Greg KH
2009-02-10 19:00 ` [patch 20/53] eeepc-laptop: fix oops when changing backlight brightness during eeepc-laptop init Greg KH
2009-02-10 19:00 ` [patch 21/53] eeepc-laptop: Add support for extended hotkeys Greg KH
2009-02-10 19:00 ` [patch 22/53] e1000: fix bug with shared interrupt during reset Greg KH
2009-02-10 19:00 ` [patch 23/53] e1000: Fix PCI enable to honor the need_ioport flag Greg KH
2009-02-10 19:00 ` [patch 24/53] agp/intel: add support for G41 chipset Greg KH
2009-02-10 19:00 ` [patch 25/53] agp/intel: Fix broken ® symbol in device name Greg KH
2009-02-10 19:00 ` [patch 26/53] ALSA: hda - Add quirk for FSC Amilo Xi2550 Greg KH
2009-02-10 19:00 ` [patch 27/53] ALSA: hda - Add missing COEF initialization for ALC887 Greg KH
2009-02-10 19:00 ` [patch 28/53] ALSA: hda - Add missing initialization for ALC272 Greg KH
2009-02-10 19:00 ` [patch 29/53] asus_acpi: Add R1F support Greg KH
2009-02-10 19:00 ` [patch 30/53] panasonic-laptop: fix X[ ARRAY_SIZE(X) ] Greg KH
2009-02-10 19:00 ` [patch 31/53] ACPI: Skip the first two elements in the _BCL package Greg KH
2009-02-10 19:00 ` [patch 32/53] ACPI: proc_dir_entry video/VGA already registered Greg KH
2009-02-10 19:00 ` [patch 33/53] ACPI: disable ACPI cleanly when bad RSDP found Greg KH
2009-02-10 19:00 ` [patch 34/53] ACPICA: Fix table entry truncation calculation Greg KH
2009-02-10 19:00 ` Greg KH [this message]
2009-02-10 19:00 ` [patch 36/53] PCI: return error on failure to read PCI ROMs Greg KH
2009-02-10 19:01 ` [patch 37/53] seq_file: move traverse so it can be used from seq_read Greg KH
2009-02-10 19:01 ` [patch 38/53] seq_file: fix big-enough lseek() + read() Greg KH
2009-02-10 19:01 ` [patch 39/53] serial: set correct baud_base for Oxford Semiconductor Ltd EXSYS EX-41092 Dual 16950 Serial adapter Greg KH
2009-02-10 19:01 ` [patch 40/53] Add support for 8-port RS-232 MIC-3620 from advantech Greg KH
2009-02-10 19:01 ` [patch 41/53] mm: fix error case in mlock downgrade reversion Greg KH
2009-02-10 19:01 ` [patch 42/53] elf core dump: fix get_user use Greg KH
2009-02-10 19:01 ` [patch 43/53] ACPI: video: Fix reversed brightness behavior on ThinkPad SL series Greg KH
2009-02-10 19:01 ` [patch 44/53] ipw2200: fix scanning while associated Greg KH
2009-02-10 19:01 ` [patch 45/53] XFS: set b_error from bio error in xfs_buf_bio_end_io Greg KH
2009-02-10 19:01 ` [patch 46/53] Revert USB: option: add Pantech cards Greg KH
2009-02-10 19:01 ` [patch 47/53] USB: option: New mobile broadband modems to be supported Greg KH
2009-02-10 19:01 ` [patch 48/53] USB: new id for ti_usb_3410_5052 driver Greg KH
2009-02-10 19:01 ` [patch 49/53] USB: two more usb ids for ti_usb_3410_5052 Greg KH
2009-02-10 19:01 ` [patch 50/53] USB: usb-storage: add Pentax to the bad-vendor list Greg KH
2009-02-10 19:01 ` [patch 51/53] sata_via: Add VT8261 support Greg KH
2009-02-10 19:01 ` [patch 52/53] nbd: do not allow two clients at the same time Greg KH
2009-02-10 19:01 ` [patch 53/53] sctp: Fix another socket race during accept/peeloff Greg KH
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20090210190057.GJ14308@kroah.com \
--to=gregkh@suse.de \
--cc=achiang@hp.com \
--cc=akpm@linux-foundation.org \
--cc=alan@lxorguk.ukuu.org.uk \
--cc=cavokz@gmail.com \
--cc=cebbert@redhat.com \
--cc=chuckw@quantumlinux.com \
--cc=davej@redhat.com \
--cc=eteo@redhat.com \
--cc=jake@lwn.net \
--cc=jbarnes@virtuousgeek.org \
--cc=jmforbes@linuxtx.org \
--cc=linux-kernel@vger.kernel.org \
--cc=mkrufky@linuxtv.org \
--cc=rbranco@la.checkpoint.com \
--cc=rdunlap@xenotime.net \
--cc=reviews@ml.cw.f00f.org \
--cc=shaohua.li@intel.com \
--cc=stable@kernel.org \
--cc=torvalds@linux-foundation.org \
--cc=tytso@mit.edu \
--cc=w@1wt.eu \
--cc=zwane@arm.linux.org.uk \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -713,9 +713,9 @@ void pcie_aspm_exit_link_state(struct pc
/*
* All PCIe functions are in one slot, remove one function will remove
- * the the whole slot, so just wait
+ * the whole slot, so just wait until we are the last function left.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox